@@ -1,5 +1,5 @@
 
-""" A client library for accessing Minikai API """
+""" A client library for accessing Minikai Public API """
 from .client import AuthenticatedClient, Client
 
 __all__ = (
